@@ -66,6 +66,13 @@ def format_airdate(aired, now=None):
         now, then, "tomorrow", prefix="in ")
 
 
+def format_days(days):
+    if days == 1:
+        return "1 day"
+
+    return "{0} days".format(days)
+
+
 def print_wrapped(text, indent=""):
     wrapper = textwrap.TextWrapper()
     wrapper.initial_indent = indent
@@ -181,6 +188,7 @@ def format_compact_list(items, item_format=u"{0}"):
 def print_series(
     term, series,
     seasons=None,
+    ignored_seasons=set(),
     series_dao=None,
     indent=u"",
 ):
@@ -207,6 +215,9 @@ def print_series(
     print term.cyan(u"Seasons")
 
     for season_number, season_episodes in sorted(seasons.items()):
+        if season_number in ignored_seasons:
+            continue
+
         if len(seasons) != 1:
             season_episodes = None
 
